@@ -175,9 +175,17 @@ class BorutaShap:
 
         X_missing = self.X.isnull().any().any()
         Y_missing = self.missing_values_y()
+        
+        models_to_check = ('xgb', 'catboost', 'lgbm')
 
+        model_name = str(type(self.model)).lower()
         if X_missing or Y_missing:
-            raise ValueError('There are missing values in your Data')
+
+            if model_name.startswith(models_to_check):
+                print('Warning there are missing values in your data !')
+
+            else:
+                raise ValueError('There are missing values in your Data')
         
         else:
             pass
@@ -196,7 +204,7 @@ class BorutaShap:
 
         if self.train_or_test.lower() == 'test':
             # keeping the same naming convenetion as to not add complexit later on
-            self.X_boruta_train, self.X_boruta, self.y_train, self.y_test = train_test_split(self.X_boruta,
+            self.X_boruta_train, self.X_boruta_test, self.y_train, self.y_test = train_test_split(self.X_boruta,
                                                                                             self.y,
                                                                                             test_size=0.3,
                                                                                             random_state=self.random_state)
@@ -245,7 +253,8 @@ class BorutaShap:
 
     
  
-    def fit(self, X, y, n_trials = 20, random_state=0, sample=False, train_or_test = 'test'):
+    def fit(self, X, y, n_trials = 20, random_state=0, sample=False,
+            train_or_test = 'test', normalize=True, verbose=True):
 
         """
         The main body of the program this method it computes the following
@@ -289,7 +298,7 @@ class BorutaShap:
             A random state for reproducibility of results
 
         Sample: Boolean
-            if true then the a rowise sample of the data will be used to calculate the feature importance values
+            if true then a rowise sample of the data will be used to calculate the feature importance values
 
         sample_fraction: float
             The sample fraction of the original data used in calculating the feature importance values only
@@ -298,6 +307,12 @@ class BorutaShap:
         train_or_test: string
             Decides whether the feature improtance should be calculated on out of sample data see the dicussion here.
             https://compstat-lmu.github.io/iml_methods_limitations/pfi-data.html#introduction-to-test-vs.training-data
+
+        normalize: boolean
+            if true the importance values will be normalized using the z-score formula
+
+        verbose: Boolean
+            a flag indicator to print out all the rejected or accepted features.
        
         """
         
@@ -338,16 +353,16 @@ class BorutaShap:
 
                 self.Check_if_chose_train_or_test_and_train_model()
 
-                self.X_feature_import, self.Shadow_feature_import = self.feature_importance()
+                self.X_feature_import, self.Shadow_feature_import = self.feature_importance(normalize=normalize)
                 self.update_importance_history()
                 self.hits += self.calculate_hits()
                 self.test_features(iteration=trial+1)
 
         self.store_feature_importance()
-        self.calculate_rejected_accepted_tentative()
+        self.calculate_rejected_accepted_tentative(verbose=verbose)
 
 
-    def calculate_rejected_accepted_tentative(self):
+    def calculate_rejected_accepted_tentative(self, verbose):
 
         """
         Figures out which features have been either accepted rejeected or tentative
@@ -362,9 +377,10 @@ class BorutaShap:
         self.accepted  = list(set(self.flatten_list(self.accepted_columns)))
         self.tentative = list(set(self.all_columns) - set(self.rejected + self.accepted))
 
-        print(str(len(self.accepted))  + ' attributes confirmed important: ' + str(self.accepted))
-        print(str(len(self.rejected))  + ' attributes confirmed unimportant: ' + str(self.rejected))
-        print(str(len(self.tentative)) + ' tentative attributes remains: ' + str(self.tentative))
+        if verbose:
+            print(str(len(self.accepted))  + ' attributes confirmed important: ' + str(self.accepted))
+            print(str(len(self.rejected))  + ' attributes confirmed unimportant: ' + str(self.rejected))
+            print(str(len(self.tentative)) + ' tentative attributes remains: ' + str(self.tentative))
 
 
 
@@ -523,12 +539,19 @@ class BorutaShap:
             Datframe with random permutations of the original columns.
         """
         self.X_shadow = self.X.apply(np.random.permutation)
+        # append
+        obj_col = self.X_shadow.select_dtypes("object").columns.tolist()
+        if obj_col ==[] :
+             pass
+        else :
+             self.X_shadow[obj_col] =self.X_shadow[obj_col].astype("category")
+
         self.X_shadow.columns = ['shadow_' + feature for feature in self.X.columns]
         self.X_boruta = pd.concat([self.X, self.X_shadow], axis = 1)
         
         col_types = self.X_boruta.dtypes
         self.X_categorical = list(col_types[(col_types=='category' ) | (col_types=='object')].index)
-
+        
 
     @staticmethod
     def calculate_Zscore(array):
@@ -547,7 +570,7 @@ class BorutaShap:
         return [(element-mean_value)/std_value for element in array]
 
 
-    def feature_importance(self):
+    def feature_importance(self, normalize):
 
         """
         Caculates the feature importances scores of the model
@@ -555,7 +578,10 @@ class BorutaShap:
         Parameters
         ----------
         importance_measure: string
-            allows the user to choose either the Shap or Gini importance metrics 
+            allows the user to choose either the Shap or Gini importance metrics
+
+        normalize: boolean
+            if true the importance values will be normalized using the z-score formula
 
         Returns:
             array of normalized feature importance scores for both the shadow and original features.
@@ -570,14 +596,21 @@ class BorutaShap:
 
             self.explain()
             vals = self.shap_values
-            vals = self.calculate_Zscore(vals)
+
+            if normalize:
+                vals = self.calculate_Zscore(vals)
 
             X_feature_import = vals[:len(self.X.columns)]
             Shadow_feature_import = vals[len(self.X_shadow.columns):]
 
+
         elif self.importance_measure == 'gini':
             
-                feature_importances_ = self.calculate_Zscore(np.abs(self.model.feature_importances_))
+                feature_importances_ =  np.abs(self.model.feature_importances_)
+                
+                if normalize:
+                    feature_importances_ = self.calculate_Zscore(feature_importances_)
+
                 X_feature_import = feature_importances_[:len(self.X.columns)]
                 Shadow_feature_import = feature_importances_[len(self.X.columns):]
 
@@ -585,6 +618,7 @@ class BorutaShap:
 
             raise ValueError('No Importance_measure was specified select one of (shap, gini)')
 
+
         return X_feature_import, Shadow_feature_import
 
 
@@ -1002,4 +1036,4 @@ def load_data(data_type='classification'):
         raise ValueError("No data_type was specified, use either 'classification' or 'regression'")
   
 
-    return X, y
\ No newline at end of file
+    return X, y
